# geometry_to_geojson

Convert a Shapely geometry (WKT) to GeoJSON using shapely.geometry.mapping.

**Arguments:**

- `geometry` (str): WKT string of the geometry.

**Returns:**

- Dictionary with status, message, and GeoJSON representation.
